@@ -28,3 +28,22 @@ def corr_matrix(df):
     # generar el dibujo
     plt.show()
 
+
+def plot_boxplots(data, norm = True):
+    import matplotlib.pyplot as plt
+    import pandas as pd
+    import seaborn as sns
+    
+    if norm == True:
+        df = (data - data.mean()) / data.std()
+    else:
+        df = data
+
+    plt.figure( figsize=(16, 7))
+    plt.title("Boxplots")
+    sns.set_style("white")
+    bx_plot = sns.boxplot(data=df)
+    plt.xticks(rotation=90)
+    plt.xlabel("variables")
+    plt.ylabel("normalized values")
+    plt.show()
